@@ -18,6 +18,7 @@ log = logging.getLogger(__name__)
 class HttpClient(object):
     """Client that performs HTTP requests."""
 
+    ip_address = None
     endpoint = None
 
     def __enter__(self):
@@ -58,25 +59,25 @@ class HttpClient(object):
             else:
                 response.raise_for_status()
         except exceptions.ConnectTimeout:
-            log.exception("The connection timed out to %s.", self.endpoint)
-            raise ConnectionTimeoutException(self.endpoint)
+            log.error("The connection timed out to %s.", self.ip_address)
+            raise ConnectionTimeoutException(self.ip_address)
         except exceptions.ConnectionError:
-            log.exception("A connection error occurred to %s.", self.endpoint)
+            log.error("A connection error occurred to %s.", self.ip_address)
             raise
         except exceptions.URLRequired:
-            log.exception("%s is an invalid URL", cmd_url)
+            log.error("%s is an invalid URL", cmd_url)
             raise
         except exceptions.TooManyRedirects:
-            log.exception("Too many redirects with request to %s.", cmd_url)
+            log.error("Too many redirects with request to %s.", cmd_url)
             raise
         except exceptions.Timeout:
-            log.exception("A connection %s has timed out.", self.endpoint)
+            log.error("A connection %s has timed out.", self.ip_address)
             raise
         except exceptions.HTTPError:
-            log.exception("A HTTP error occurred with request to %s.", cmd_url)
+            log.error("A HTTP error occurred with request to %s.", cmd_url)
             raise KempTechApiException(msg=response.text)
         except exceptions.RequestException:
-            log.exception("An error occurred with request to %s.", cmd_url)
+            log.error("An error occurred with request to %s.", cmd_url)
             raise
         return response.text
 
@@ -244,7 +245,10 @@ class LoadMaster(HttpClient):
 
     def upload_template(self, file):
         response = self._post('/uploadtemplate', file)
-        return ApiXmlHelper.is_successful(response)
+        if ApiXmlHelper.is_successful(response):
+            return ApiXmlHelper.parse_to_dict(response)
+        else:
+            raise KempTechApiException(ApiXmlHelper.get_error_msg(response))
 
     def list_templates(self):
         response = self._get('/listtemplates')
@@ -273,3 +277,10 @@ class LoadMaster(HttpClient):
             return ApiXmlHelper.parse_to_dict(response)
         else:
             raise KempTechApiException(ApiXmlHelper.get_error_msg(response))
+
+    def get_sdn_info(self):
+        response = self._get('/sdninfo')
+        if ApiXmlHelper.is_successful(response):
+            return ApiXmlHelper.parse_to_dict(response)
+        else:
+            raise KempTechApiException(ApiXmlHelper.get_error_msg(response))
